# -*- test-case-name: txdav -*-
##
# Copyright (c) 2010-2015 Apple Inc. All rights reserved.
#
# Licensed under the Apache License, Version 2.0 (the "License");
# you may not use this file except in compliance with the License.
# You may obtain a copy of the License at
#
# http://www.apache.org/licenses/LICENSE-2.0
#
# Unless required by applicable law or agreed to in writing, software
# distributed under the License is distributed on an "AS IS" BASIS,
# WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
# See the License for the specific language governing permissions and
# limitations under the License.
##

"""
Calendar & contacts data store.
"""

#
# FIXME: 'txdav' should be renamed to 'datastore' and shoul not be
# WebDAV-specific.
#
# (That means txdav.xml should be pulled out, for example, as that is
# WebDAV-specific.)
#
